==> apimodule-1.0.5.tar.gz: lib/msimpersaa/response/str_response.dart <==
class StrResponse {
  bool con;
  String msg;
  List<StrResults> results;

  StrResponse({this.con, this.msg, this.results});

  StrResponse.fromJson(Map<String, dynamic> json) {
    con = json['con'];
    msg = json['msg'];
    if (json['results'] != null) {
      results = <StrResults>[];
      json['results'].forEach((v) {
        results.add(StrResults.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['con'] = this.con;
    data['msg'] = this.msg;
    if (this.results != null) {
      data['results'] = this.results.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class StrResults {
  int id;
  String noRegistrasi;
  String kompetensi;
  String noSrtKompetensi;
  String tanggalTerbit;
  String tanggalBerlaku;
  String documen;
  String pathFile;

  StrResults(
      {this.id,
      this.noRegistrasi,
      this.kompetensi,
      this.noSrtKompetensi,
      this.tanggalTerbit,
      this.tanggalBerlaku,
      this.documen,
      this.pathFile});

  StrResults.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    noRegistrasi = json['no_registrasi'];
    kompetensi = json['kompetensi'];
    noSrtKompetensi = json['no_srt_kompetensi'];
    tanggalTerbit = json['tanggal_terbit'];
    tanggalBerlaku = json['tanggal_berlaku'];
    documen = json['dokumen'];
    pathFile = json['path_file'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['id'] = this.id;
    data['no_registrasi'] = this.noRegistrasi;
    data['kompetensi'] = this.kompetensi;
    data['no_srt_kompetensi'] = this.noSrtKompetensi;
    data['tanggal_terbit'] = this.tanggalTerbit;
    data['tanggal_berlaku'] = this.tanggalBerlaku;
    data['dokumen'] = this.documen;
    data['path_file'] = this.pathFile;
    return data;
  }
}

==> apimodule-1.1.5.tar.gz: lib/msimpersaa/response/str_response.dart <==
class StrResponse {
  bool con;
  String msg;
  List<StrResults> results;

  StrResponse({this.con, this.msg, this.results});

  StrResponse.fromJson(Map<String, dynamic> json) {
    con = json['con'];
    msg = json['msg'];
    if (json['results'] != null) {
      results = <StrResults>[];
      json['results'].forEach((v) {
        results.add(StrResults.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['con'] = this.con;
    data['msg'] = this.msg;
    if (this.results != null) {
      data['results'] = this.results.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class StrResults {
  int id;
  String noRegistrasi;
  String kompetensi;
  String noSrtKompetensi;
  String tanggalTerbit;
  String tanggalBerlaku;
  String document;
  String pathFile;

  StrResults(
      {this.id,
      this.noRegistrasi,
      this.kompetensi,
      this.noSrtKompetensi,
      this.tanggalTerbit,
      this.tanggalBerlaku,
      this.document,
      this.pathFile});

  StrResults.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    noRegistrasi = json['no_registrasi'];
    kompetensi = json['kompetensi'];
    noSrtKompetensi = json['no_srt_kompetensi'];
    tanggalTerbit = json['tanggal_terbit'];
    tanggalBerlaku = json['tanggal_berlaku'];
    document = json['dokumen'];
    pathFile = json['path_file'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['id'] = this.id;
    data['no_registrasi'] = this.noRegistrasi;
    data['kompetensi'] = this.kompetensi;
    data['no_srt_kompetensi'] = this.noSrtKompetensi;
    data['tanggal_terbit'] = this.tanggalTerbit;
    data['tanggal_berlaku'] = this.tanggalBerlaku;
    data['dokumen'] = this.document;
    data['path_file'] = this.pathFile;
    return data;
  }
}
